.. 结构可以直接使用
.. trainer-xy' documentation master file

trainer-xy : 训练仪表盘
=======================

训练过程可视化。动态绘制训练的 loss 等信息，并且可以发送消息来暂停/继续训练进程。
由于训练进程和可视化的进程是独立的，所以关闭可视化进程不会影响训练进程，且重新打开可视化进程时，
仍然能正常显示。


.. whatsnew/index is automatically generated (see conf.py for Sphinx and dev/gendoc.py).


.. toctree::
    :maxdepth: 3

    getting_started/index
    user_guide/index
    reference/index
    
.. development/index

.. whatsnew/index

